# Introduction

Xeye is a python package for create in automatic and frendly way, using just your pc and a usb camera (even with your integreted pc camera), dataset for build deep learning model in order to develop computer vision application. 

